@@ -79,8 +79,9 @@ create_data_bins <- function(input.obj, bins)
   #dat.temp$phase<-input.obj$phase[wrk]
   dat.temp$n.phe<-input.obj$n.phe
   dat.temp$pheno<-input.obj$pheno
-  dat.temp$CHROM <- input.obj$CHROM[wrk]
-  dat.temp$POS <- input.obj$POS[wrk]
+  if(!is.null(input.obj$CHROM)) dat.temp$CHROM <- input.obj$CHROM[wrk]
+  if(!is.null(input.obj$POS)) dat.temp$POS <- input.obj$POS[wrk]
+  if(!is.null(input.obj$ref_alt_alleles)) dat.temp$ref_alt_alleles <- input.obj$ref_alt_alleles[wrk,]
   dat.temp$error <- input.obj$error[wrk + rep(c(0:(input.obj$n.ind-1))*input.obj$n.mar, each=length(wrk)),]
  return(dat.temp)
 }
@@ -130,7 +131,7 @@ add_redundants <- function(sequence, onemap.obj, bins){
   
   for(i in 1:length(new.seq.rf)){
     new.seq.rf[[i]] <- rep(new.seq.rf[[i]], each = sizes[i])
-    new.phases[[i]] <- rep(new.phases[[i]], each = sizes[i])
+    if(inherits(onemap.obj, c("f2", "outcross", "backcross")))  new.phases[[i]] <- rep(new.phases[[i]], each = sizes[i])
   }
   
   new.seq.rf <- do.call(c, new.seq.rf)
